@@ -54,10 +54,10 @@
 #define HAVE_STRCASESTR 1
 
 /* Define to 1 if you have the `strlcat' function. */
-#undef HAVE_STRLCAT
+#define HAVE_STRLCAT 1
 
 /* Define to 1 if you have the `strlcpy' function. */
-#undef HAVE_STRLCPY
+#define HAVE_STRLCPY 1
 
 /* Define to 1 if you have the `strncasecmp' function. */
 #define HAVE_STRNCASECMP 1
@@ -135,7 +135,7 @@
 #define XORGSERVER 1
 
 /* Current Xorg version */
-#define XORG_VERSION_CURRENT 12101007
+#define XORG_VERSION_CURRENT 12101009
 
 /* Build Xv Extension */
 #define XvExtension 1
